<?php
/*
Plugin Name: Distictions
Plugin URI:  http://www.sdhsuchy.org/wp-distinctions/
Description: Add preview of ribbons and distinctions that Czech volunteer firefighters can obtain in the Czech Republic.
Version:     1.3
Author:      Radek Oslejsek
Author URI:  http://www.sdhsuchy.org/
License:     GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Domain Path: /languages
Text Domain: distinctions
*/

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

//Screen Styles
add_action('wp_enqueue_scripts', 'ro_distinctions_css');
function ro_distinctions_css() {
    wp_register_style( 'distinctions', plugins_url( '/css/distinctions.css' , __FILE__ ) );
    wp_enqueue_style( 'distinctions' );
}

// Complete set of all ribbons divided into groups via "Fruitful Shortcodes plugin" tabs
require_once("conf/distinctions-conf.php");
function ro_distinctions_shortcode( $atts ) {
    global $wp_distinctions;

    $a = shortcode_atts( array(
        'group' => 'all',
	'tabcolor' => '#841a1a'
    ), $atts );

    if ($a{'group'} == 'all') { // check plugin dependencies to display all groups
        if (!function_exists('fruitful_tabs_shortcode') || !function_exists('fruitful_tab_shortcode')) {
	    return "Distinctions error: Fruitful Shortcodes plugin required to display all distictions";
        }
	foreach ($wp_distinctions as $abbrev => $file) {
	    //$ret .= fruitful_tab_shortcode(array("title" => $abbrev));
	    $content .= '[fruitful_tab title="' . $abbrev . '"]';
	    $content .= dist_tab($file); 
	    $content .= '[/fruitful_tab]';
    	}
	$ret .= fruitful_tabs_shortcode(array("type" => "default", "width" => "100%", "fit" => "false", "tabcolor" => $a{'tabcolor'}), $content);
    } else if (isset($a{'group'})) { // single group
	$ret .= dist_tab($a{'group'}, true);
    } else {
	return "Distinctions error: invalid attribute";
    }

    $ret .= '<div style="text-align: left; font-size: 85%; color: #808080;">';
    $ret .= 'Zdroj: <a href="http://www.sdhsuchy.org/" target="_blank">www.sdhsuchy.org</a>. ';
    $ret .= 'Další tipy na vyznamenání posílejte na adresu <a href="mailto:radek.oslejsek@sdhsuchy.org">radek.oslejsek@sdhsuchy.org</a>.';
    $ret .= '</div>';

    return $ret;
}
add_shortcode( 'distinctions', 'ro_distinctions_shortcode' ); 


/**** OBSOLETE: This code uses Tabby plugin *****
// Complete set of all ribbons divided into groups via "tabby" tabs
//require_once("conf/distinctions-conf.php");
function ro_distinctions_shortcode( $atts ) {
    global $wp_distinctions;

    $a = shortcode_atts( array(
        'group' => 'all'
    ), $atts );

    if ($a{'group'} == 'all') { // check tabby dependencies to display all groups
        if (!function_exists('fruitful_tabs_shortcode') || !function_exists('fruitful_tab_shortcode')) {
	    return "Distinctions error: Fruitful Shortcodes plugin required to display all distictions";
        }
	if (!function_exists('cc_shortcode_tabby')) return; // -- TABBY PLUGIN
	if (!function_exists('cc_shortcode_tabbyending')) return; // -- TABBY PLUGIN
	foreach ($wp_distinctions as $abbrev => $file) {
	    $ret .= cc_shortcode_tabby(array("title" => $abbrev)); // -- TABBY PLUGIN
	    $ret .= dist_tab($file); 
    	}	
	$ret .= cc_shortcode_tabbyending(null); // -- TABBY PLUGIN
    } else if (isset($a{'group'})) { // single group
	$ret .= dist_tab($a{'group'}, true);
    } else {
	return "Distinctions error: invalid attribute";
    }

    $ret .= '<div style="text-align: left; font-size: 85%; color: #808080;">';
    $ret .= 'Zdroj: <a href="http://www.sdhsuchy.org/" target="_blank">www.sdhsuchy.org</a>. ';
    $ret .= 'Další tipy na vyznamenání posílejte na adresu <a href="mailto:radek.oslejsek@sdhsuchy.org">radek.oslejsek@sdhsuchy.org</a>.';
    $ret .= '</div>';

    return $ret;
}
add_shortcode( 'distinctions', 'ro_distinctions_shortcode' ); 
*/

require_once("conf/ribbon-rack-conf.php");
function ro_ribbon_rack_shortcode( $atts) {
    global $ribbon_rack_conf;

    $a = shortcode_atts( array(
        'distinctions' => '',
		'ribbon-height' => '17',
		'align' => 'center',
		'columns' => 3,
		'nolink' => false
    ), $atts );

    if ($a{'distinctions'} == '') return "";

    $pq = new SplPriorityQueue();
    //foreach (split(",", $a{'distinctions'}) as $dist) {
	foreach (explode(",", $a{'distinctions'}) as $dist) {
        $match = false;
		foreach ($ribbon_rack_conf as $pattern => $priority) {
		    if (preg_match($pattern, $dist) == 1) {
				$pq->insert($dist, $priority);
				$match = true;
				break;
	    	}
        }
		if (!$match) $pq->insert($dist, 0);
    }

    //echo "count ->" . $pq->count() . PHP_EOL; // Count the elements

    // Sets the mode of extraction (EXTR_DATA, EXTR_PRIORITY, EXTR_BOTH)
    $pq->setExtractFlags(SplPriorityQueue::EXTR_BOTH);

    // Go at the node from the top of the queue
    $pq->top();

    $num_rows = floor(($pq->count() - 1) / $a{'columns'}) + 1;
    $first_row_size = $pq->count() % $a{'columns'};

    if (!$a{'nolink'}) $ret .= '<a href="http://www.sdhsuchy.org/stuzky-vyznamenani-hasicu">';

    $ret .= "\n". '<div style="line-height: 0.8; display: inline-block; text-align: ' . $a{'align'} . ';">' . "\n"; // block
    for ($i = 0; $i < $num_rows; $i++) { // for each line
	$ret .= '  <div>' . "\n"; // line
        $cols = ($i == 0 && $first_row_size > 0) ? $first_row_size : $a{'columns'};
	for ($j = 0; $j < $cols; $j++) { // for each ribbon
	   $img_name = $pq->current()['data'];
    	   $ret .= '<img src="' . plugins_url( "ribbons/png/$img_name.png", __FILE__ ) . '" alt="' . $img_name .'" title="' . $img_name . '" height="' . $a{'ribbon-height'} . '"  style="margin: 0px; padding: 0px; border: 0px;"/>';
	   $pq->next();
	}
	$ret .= "  </div>\n"; // line
    }
    $ret .= "</div>\n"; // block

    if (!$a{'nolink'}) $ret .= '</a>';

    return $ret;
}
add_shortcode( 'ribbon_rack', 'ro_ribbon_rack_shortcode' );



// Set of distinctions (single tab)
function dist_tab( $grp_file, $silent = false ) {
    require("conf/groups/". $grp_file . ".php");
    if (!$silent) {
       $ret .= '<h2>' . $wp_ribbon_set['name'] . '</h2>';
       $ret .= '<div style="text-align: justify; margin-bottom: 40px;">';
       $ret .= $wp_ribbon_set['desc'];
       $ret .= '</div>';
    }
    foreach ($wp_ribbon_set['ribbons'] as $ribbon) {
	$ret .= dist_ribbon($ribbon);
    }
    if (isset($wp_ribbon_set['footer'])) {
        $ret .= '<div style="text-align: justify; font-size: 85%; color: #808080; border-top: 1px solid #f0f0f0; padding-top: 15px;">';
 	$ret .= $wp_ribbon_set['footer'];
	$ret .= '</div>';
    }
    return $ret;
}

function dist_ribbon( $ribbon, $show_photo = true ) {
    require("conf/ribbons/". $ribbon . ".php");

    if (!file_exists(plugin_dir_path(__FILE__) . "ribbons/photo/$img_name.png")) {
	$show_photo = false;
    }

    $ret .= '<div class="ribbon">';

    $ret .= '<h3>' . $wp_ribbon['name'] . '</h3>';
    $ret .= '<div class="ribbon-icon">';
    $first = true;
    foreach ($wp_ribbon['img'] as $img_name) {
	if (!$first) $ret .= '<br/>';
	$first = false;
	$ribbon_class = "ribbon-" . $img_name;
	$photo_class = "photo-" . $img_name;

	if (file_exists(plugin_dir_path(__FILE__) . "ribbons/photo/$img_name.png")) {
	    $ret .= '<a href="' . plugins_url( "ribbons/photo/$img_name.png", __FILE__ ) . '" rel="lightbox"><img class="' . $ribbon_class . '" style="cursor:pointer; margin-top: 2px;" src="' . plugins_url( "ribbons/png/$img_name.png", __FILE__ ) . '" alt="' . $img_name . '" title="' . $img_name . '" onmouseover="show_distinction(\'' . $ribbon_class . '\',\'' . $photo_class . '\')") /></a>';  
	} else {
	    $ret .= '<img class="' . $ribbon_class . '" src="' . plugins_url( "ribbons/png/$img_name.png", __FILE__ ) . '" alt="' . $img_name . '" style="margin-top: 2px" title="' . $img_name . '" />';  
	}

    }
    $ret .= '</div>';

    $ret .= '<div class="ribbon-desc">';
    $ret .= '<ul>';
    foreach ($wp_ribbon['desc'] as $desc) {
	$ret .= '<li>' . $desc . '</li>';
    }
    $ret .= '</ul>';
    $ret .= '</div>';

    $ret .= '<div style="clear: left;"></div>';
    $ret .= '</div>';

    return $ret;
}

?>
